"""Trivial test program."""


hello = []


class World:

  def dominate(self):
    pass


def helloworld():
  print("hello world")
